@@ -20,10 +20,11 @@ def run(port, workers):
         - production & staging : `./manage.py run --port 8000 --workers 4`
     """
     mode = spoc.mode
+    host = "0.0.0.0"
     # FastAPI-Server
     match mode:
         case "development":
-            cmd = f"python -m uvicorn main:app --reload --port { port }"
+            cmd = f"python -m uvicorn main:app --reload --port { port } --host { host }"
         case "staging":
             cmd = f"python -m gunicorn main:app --workers { workers } --worker-class uvicorn.workers.UvicornWorker --bind 0.0.0.0:{ port }"
         case "production":
